==> haskell-time-compat-1.9.7-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 time-compat
version:              1.9.7
visibility:           public
id:                   time-compat-1.9.7-tIVZzKaKUZAuOkgomwHLj
key:                  time-compat-1.9.7-tIVZzKaKUZAuOkgomwHLj
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Ashley Yakeley
homepage:             https://github.com/haskellari/time-compat
synopsis:             Compatibility package for time
description:
    This packages tries to compat as much of @time@ features as possible.

    /TODO:/

    * Difference type @ParseTime@ and @FormatTime@ instances are missing.

    * Formatting varies depending on underlying @time@ version

    * @dayFractionToTimeOfDay@ on extreme values

category:             Time, Compatibility
abi:                  99cc231c56957117995d5b2f6c309442
exposed:              True
exposed-modules:
    Data.Time.Calendar.Compat Data.Time.Calendar.Easter.Compat
    Data.Time.Calendar.Julian.Compat Data.Time.Calendar.Month.Compat
    Data.Time.Calendar.MonthDay.Compat
    Data.Time.Calendar.OrdinalDate.Compat
    Data.Time.Calendar.Quarter.Compat
    Data.Time.Calendar.WeekDate.Compat Data.Time.Clock.Compat
    Data.Time.Clock.POSIX.Compat Data.Time.Clock.System.Compat
    Data.Time.Clock.TAI.Compat Data.Time.Compat Data.Time.Format.Compat
    Data.Time.Format.ISO8601.Compat Data.Time.LocalTime.Compat

hidden-modules:
    Data.Format Data.Time.Calendar.Private Data.Time.Calendar.Types
    Data.Time.Orphans

import-dirs:          /usr/lib/ghc-9.4.8/site-local/time-compat-1.9.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/time-compat-1.9.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/time-compat-1.9.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-time-compat
hs-libraries:         HStime-compat-1.9.7-tIVZzKaKUZAuOkgomwHLj
depends:
    base-4.17.2.1 base-orphans-0.9.3-BnQ7VdntHVR2bPjqU1A3eC
    deepseq-1.4.8.0 hashable-1.4.6.0-2hEv5lQFD6LEJdTUNcXkaI time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-time-compat/html/time-compat.haddock
haddock-html:         /usr/share/doc/haskell-time-compat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-time-compat-1.9.7-82-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 time-compat
version:              1.9.7
visibility:           public
id:                   time-compat-1.9.7-EIf11wFHdll3vNdatQ2yhc
key:                  time-compat-1.9.7-EIf11wFHdll3vNdatQ2yhc
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Ashley Yakeley
homepage:             https://github.com/haskellari/time-compat
synopsis:             Compatibility package for time
description:
    This packages tries to compat as much of @time@ features as possible.

    /TODO:/

    * Difference type @ParseTime@ and @FormatTime@ instances are missing.

    * Formatting varies depending on underlying @time@ version

    * @dayFractionToTimeOfDay@ on extreme values

category:             Time, Compatibility
abi:                  848d3279e35ba6ba4a10ef8258166102
exposed:              True
exposed-modules:
    Data.Time.Calendar.Compat Data.Time.Calendar.Easter.Compat
    Data.Time.Calendar.Julian.Compat Data.Time.Calendar.Month.Compat
    Data.Time.Calendar.MonthDay.Compat
    Data.Time.Calendar.OrdinalDate.Compat
    Data.Time.Calendar.Quarter.Compat
    Data.Time.Calendar.WeekDate.Compat Data.Time.Clock.Compat
    Data.Time.Clock.POSIX.Compat Data.Time.Clock.System.Compat
    Data.Time.Clock.TAI.Compat Data.Time.Compat Data.Time.Format.Compat
    Data.Time.Format.ISO8601.Compat Data.Time.LocalTime.Compat

hidden-modules:
    Data.Format Data.Time.Calendar.Private Data.Time.Calendar.Types
    Data.Time.Orphans

import-dirs:          /usr/lib/ghc-9.4.8/site-local/time-compat-1.9.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/time-compat-1.9.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/time-compat-1.9.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-time-compat
hs-libraries:         HStime-compat-1.9.7-EIf11wFHdll3vNdatQ2yhc
depends:
    base-4.17.2.1 base-orphans-0.9.3-21Kg0ZpixBhIWAAM72mV1W
    deepseq-1.4.8.0 hashable-1.4.6.0-2hEv5lQFD6LEJdTUNcXkaI time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-time-compat/html/time-compat.haddock
haddock-html:         /usr/share/doc/haskell-time-compat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
